# Futu API Interfaces and URLs

## Quote API

### Real-time Data

#### Subscription
接口：subscribe
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：unsubscribe
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：unsubscribe_all
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：query_subscription
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

#### Push and Callback
接口：StockQuoteHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：OrderBookHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：CurKlineHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：TickerHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：RTDataHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

接口：BrokerHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/sub.html
状态：已完成

#### Get
接口：get_market_snapshot
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-market-snapshot.html
状态：已完成

接口：get_stock_quote
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-stock-quote.html
状态：已完成

接口：get_order_book
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-order-book.html
状态：已完成

接口：get_cur_kline
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-kl.html
状态：已完成

接口：get_rt_data
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-rt.html
状态：已完成

接口：get_rt_ticker
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-ticker.html
状态：已完成

接口：get_broker_queue
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-broker.html
状态：已完成

### Basic Data
接口：get_market_state
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-market-state.html
状态：已完成

接口：get_capital_flow
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-capital-flow.html
状态：已完成

接口：get_capital_distribution
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-capital-distribution.html
状态：已完成

接口：get_owner_plate
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-owner-plate.html
状态：已完成

接口：request_history_kline
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/request-history-kline.html
状态：已完成

接口：get_rehab
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-rehab.html
状态：已完成

### Related Derivatives
接口：get_option_expiration_date
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-option-expiration-date.html
状态：已完成

接口：get_option_chain
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-option-chain.html
状态：已完成

接口：get_warrant
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-warrant.html
状态：已完成

接口：get_referencestock_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-referencestock-list.html
状态：已完成

接口：get_future_info
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-future-info.html
状态：已完成

### Market Filter
接口：get_stock_filter
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-stock-filter.html
状态：已完成

接口：get_plate_stock
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-stock.html
状态：已完成

接口：get_plate_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-list.html
状态：已完成

接口：get_stock_basicinfo
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-static-info.html
状态：已完成

接口：get_ipo_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-ipo-list.html

接口：get_global_state
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-global-state.html
状态：已完成

接口：request_trading_days
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/request-trading-days.html
状态：已完成

### Customization
接口：get_history_kl_quota
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-history-kl-quota.html
状态：已完成

接口：set_price_reminder
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/set-price-reminder.html
状态：已完成

接口：get_price_reminder
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-price-reminder.html
状态：已完成

接口：get_user_security_group
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-user-security-group.html
状态：已完成

接口：get_user_security
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-user-security.html
状态：已完成

接口：modify_user_security
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/modify-user-security.html
状态：已完成

接口：PriceReminderHandlerBase
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/set-price-reminder.html

### Plate Data
接口：get_plate_capital_flow
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-capital-flow.html
状态：已完成

接口：get_plate_kline
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-kline.html
状态：已完成

接口：get_plate_rt_kline
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-rt-kline.html
状态：已完成

接口：get_plate_rt_tick
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-rt-tick.html
状态：已完成

接口：get_plate_history_intraday
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-history-intraday.html
状态：已完成

接口：get_plate_history_tick
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-history-tick.html
状态：已完成

接口：get_plate_history_trades
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-history-trades.html
状态：已完成

接口：get_plate_history_capital_flow
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-history-capital-flow.html
状态：已完成

接口：get_plate_history_time_share
详情地址：https://openapi.futunn.com/futu-api-doc/en/quote/get-plate-history-time-share.html
状态：已完成

## Trade API

### Order
接口：place_order
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/place-order.html

接口：modify_order
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/modify-order.html

接口：cancel_order
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/cancel-order.html

### Query
接口：get_order_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-order-list.html

接口：get_position_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-position-list.html

接口：get_asset_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-asset-list.html

接口：get_acc_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-acc-list.html

接口：get_fund_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-fund-list.html

### History
接口：get_history_order_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-history-order-list.html

接口：get_history_deal_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-history-deal-list.html

接口：get_history_position_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-history-position-list.html

接口：get_history_asset_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-history-asset-list.html

接口：get_history_fund_list
详情地址：https://openapi.futunn.com/futu-api-doc/en/trade/get-history-fund-list.html 